@@ -29,6 +29,9 @@ fragment metadataEntryFragment on MetadataEntry {
   ... on IntMetadataEntry {
     intRepr
   }
+  ... on BoolMetadataEntry {
+    boolValue
+  }
   ... on JsonMetadataEntry {
     jsonString
   }
@@ -316,8 +319,8 @@ mutation($executionParams: ExecutionParams!) {
 LAUNCH_PIPELINE_REEXECUTION_MUTATION = (
     ERROR_FRAGMENT
     + """
-mutation($executionParams: ExecutionParams!) {
-  launchPipelineReexecution(executionParams: $executionParams) {
+mutation($executionParams: ExecutionParams, $reexecutionParams: ReexecutionParams) {
+  launchPipelineReexecution(executionParams: $executionParams, reexecutionParams: $reexecutionParams) {
     __typename
 
     ... on PythonError {
