@@ -3,7 +3,7 @@ import sys
 from graphql.execution.base import ResolveInfo
 from rx import Observable
 
-from dagster import check
+import dagster._check as check
 from dagster.core.events import DagsterEventType, EngineEventData
 from dagster.core.instance import DagsterInstance
 from dagster.core.storage.compute_log_manager import ComputeIOType
@@ -20,7 +20,11 @@ from .backfill import (
     create_and_launch_partition_backfill,
     resume_partition_backfill,
 )
-from .launch_execution import launch_pipeline_execution, launch_pipeline_reexecution
+from .launch_execution import (
+    launch_pipeline_execution,
+    launch_pipeline_reexecution,
+    launch_reexecution_from_parent_run,
+)
 
 
 def _force_mark_as_canceled(instance, run_id):
