@@ -1,28 +1,28 @@
-from dagster import check
-from dagster.core.execution.plan.resume_retry import get_retry_steps_from_execution_plan
+from graphql.execution.base import ResolveInfo
+
+import dagster._check as check
+from dagster.core.execution.plan.resume_retry import get_retry_steps_from_parent_run
 from dagster.core.execution.plan.state import KnownExecutionState
-from dagster.core.host_representation import ExternalPipeline
 from dagster.core.storage.pipeline_run import PipelineRunStatus
 from dagster.core.storage.tags import RESUME_RETRY_TAG
 from dagster.core.utils import make_new_run_id
 from dagster.utils import merge_dicts
-from graphql.execution.base import ResolveInfo
 
+from ...schema.errors import GrapheneNoModeProvidedError
 from ..external import ensure_valid_config, get_external_execution_plan_or_raise
-from ..utils import ExecutionParams
+from ..utils import ExecutionParams, UserFacingGraphQLError
 
 
-def compute_step_keys_to_execute(graphene_info, external_pipeline, execution_params):
+def compute_step_keys_to_execute(graphene_info, execution_params):
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
-    check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
     check.inst_param(execution_params, "execution_params", ExecutionParams)
 
     instance = graphene_info.context.instance
 
     if not execution_params.step_keys and is_resume_retry(execution_params):
         # Get step keys from parent_run_id if it's a resume/retry
-        return get_retry_steps_from_execution_plan(
-            instance, external_pipeline, execution_params.execution_metadata.parent_run_id
+        return get_retry_steps_from_parent_run(
+            instance, execution_params.execution_metadata.parent_run_id
         )
     else:
         known_state = None
@@ -41,16 +41,26 @@ def is_resume_retry(execution_params):
 
 
 def create_valid_pipeline_run(graphene_info, external_pipeline, execution_params):
-    ensure_valid_config(external_pipeline, execution_params.mode, execution_params.run_config)
+    if execution_params.mode is None and len(external_pipeline.available_modes) > 1:
+        raise UserFacingGraphQLError(
+            GrapheneNoModeProvidedError(external_pipeline.name, external_pipeline.available_modes)
+        )
+    elif execution_params.mode is None and len(external_pipeline.available_modes) == 1:
+        mode = external_pipeline.available_modes[0]
+
+    else:
+        mode = execution_params.mode
+
+    ensure_valid_config(external_pipeline, mode, execution_params.run_config)
 
     step_keys_to_execute, known_state = compute_step_keys_to_execute(
-        graphene_info, external_pipeline, execution_params
+        graphene_info, execution_params
     )
 
     external_execution_plan = get_external_execution_plan_or_raise(
         graphene_info=graphene_info,
         external_pipeline=external_pipeline,
-        mode=execution_params.mode,
+        mode=mode,
         run_config=execution_params.run_config,
         step_keys_to_execute=step_keys_to_execute,
         known_state=known_state,
@@ -65,11 +75,15 @@ def create_valid_pipeline_run(graphene_info, external_pipeline, execution_params
         run_id=execution_params.execution_metadata.run_id
         if execution_params.execution_metadata.run_id
         else make_new_run_id(),
+        asset_selection=frozenset(execution_params.selector.asset_selection)
+        if execution_params.selector.asset_selection
+        else None,
+        solid_selection=execution_params.selector.solid_selection,
         solids_to_execute=frozenset(execution_params.selector.solid_selection)
         if execution_params.selector.solid_selection
         else None,
         run_config=execution_params.run_config,
-        mode=execution_params.mode,
+        mode=mode,
         step_keys_to_execute=step_keys_to_execute,
         tags=tags,
         root_run_id=execution_params.execution_metadata.root_run_id,
