@@ -2,7 +2,7 @@ import sys
 
 from graphql.execution.base import ResolveInfo
 
-from dagster import check
+import dagster._check as check
 from dagster.config.validate import validate_config_from_snap
 from dagster.core.host_representation import ExternalPipeline, PipelineSelector, RepositorySelector
 from dagster.core.workspace.context import BaseWorkspaceRequestContext
@@ -29,7 +29,7 @@ def get_external_pipeline_or_raise(graphene_info, selector):
 
     full_pipeline = get_full_external_pipeline_or_raise(graphene_info, selector)
 
-    if selector.solid_selection is None:
+    if selector.solid_selection is None and selector.asset_selection is None:
         return full_pipeline
 
     return get_subset_external_pipeline(graphene_info.context, selector)
