@@ -1,4 +1,5 @@
-from typing import TYPE_CHECKING, List, Optional, Union
+# pylint: disable=missing-graphene-docstring
+from typing import TYPE_CHECKING, List, Optional, Sequence, Union
 
 import graphene
 from dagster_graphql.implementation.events import iterate_metadata_entries
@@ -9,7 +10,8 @@ from dagster_graphql.schema.solids import (
     build_solid_definition,
 )
 
-from dagster import AssetKey, check
+from dagster import AssetKey
+from dagster import _check as check
 from dagster.core.host_representation import ExternalRepository, RepositoryLocation
 from dagster.core.host_representation.external_data import (
     ExternalAssetNode,
@@ -40,7 +42,7 @@ class GrapheneAssetDependency(graphene.ObjectType):
         self,
         repository_location: RepositoryLocation,
         external_repository: ExternalRepository,
-        input_name: str,
+        input_name: Optional[str],
         asset_key: AssetKey,
         materialization_loader: Optional[BatchMaterializationLoader] = None,
         depended_by_loader: Optional[CrossRepoAssetDependedByLoader] = None,
@@ -84,12 +86,13 @@ class GrapheneAssetNode(graphene.ObjectType):
         beforeTimestampMillis=graphene.String(),
         limit=graphene.Int(),
     )
-    computeKind: graphene.String
+    computeKind = graphene.String()
     dependedBy = non_null_list(GrapheneAssetDependency)
     dependedByKeys = non_null_list(GrapheneAssetKey)
     dependencies = non_null_list(GrapheneAssetDependency)
     dependencyKeys = non_null_list(GrapheneAssetKey)
     description = graphene.String()
+    graphName = graphene.String()
     id = graphene.NonNull(graphene.ID)
     jobNames = non_null_list(graphene.String)
     jobs = non_null_list(GraphenePipeline)
@@ -101,6 +104,7 @@ class GrapheneAssetNode(graphene.ObjectType):
     metadata_entries = non_null_list(GrapheneMetadataEntry)
     op = graphene.Field(GrapheneSolidDefinition)
     opName = graphene.String()
+    opNames = non_null_list(graphene.String)
     partitionKeys = non_null_list(graphene.String)
     partitionDefinition = graphene.String()
     repository = graphene.NonNull(lambda: external.GrapheneRepository)
@@ -137,8 +141,8 @@ class GrapheneAssetNode(graphene.ObjectType):
         super().__init__(
             id=external_asset_node.asset_key.to_string(),
             assetKey=external_asset_node.asset_key,
-            opName=external_asset_node.op_name,
             description=external_asset_node.op_description,
+            opName=external_asset_node.op_name,
         )
 
     @property
@@ -153,7 +157,7 @@ class GrapheneAssetNode(graphene.ObjectType):
     def external_asset_node(self) -> ExternalAssetNode:
         return self._external_asset_node
 
-    def get_partition_keys(self) -> List[str]:
+    def get_partition_keys(self) -> Sequence[str]:
         # TODO: Add functionality for dynamic partitions definition
         partitions_def_data = self._external_asset_node.partitions_def_data
         if partitions_def_data:
@@ -168,7 +172,7 @@ class GrapheneAssetNode(graphene.ObjectType):
 
     def resolve_assetMaterializations(
         self, graphene_info, **kwargs
-    ) -> List[GrapheneMaterializationEvent]:
+    ) -> Sequence[GrapheneMaterializationEvent]:
         from ..implementation.fetch_assets import get_asset_materializations
 
         beforeTimestampMillis: Optional[str] = kwargs.get("beforeTimestampMillis")
@@ -216,12 +220,12 @@ class GrapheneAssetNode(graphene.ObjectType):
         # CrossRepoAssetDependedByLoader class loads cross-repo asset dependencies workspace-wide.
         # In order to avoid recomputing workspace-wide values per asset node, we add a loader
         # that batch loads all cross-repo dependencies for the whole workspace.
-        check.invariant(
+        _depended_by_loader = check.not_none(
             self._depended_by_loader,
             "depended_by_loader must exist in order to resolve dependedBy nodes",
         )
 
-        depended_by_asset_nodes = self._depended_by_loader.get_cross_repo_dependent_assets(
+        depended_by_asset_nodes = _depended_by_loader.get_cross_repo_dependent_assets(
             self._repository_location.name,
             self._external_repository.name,
             self._external_asset_node.asset_key,
@@ -243,21 +247,21 @@ class GrapheneAssetNode(graphene.ObjectType):
                 input_name=dep.input_name,
                 asset_key=dep.downstream_asset_key,
                 materialization_loader=materialization_loader,
-                depended_by_loader=self._depended_by_loader,
+                depended_by_loader=_depended_by_loader,
             )
             for dep in depended_by_asset_nodes
         ]
 
-    def resolve_dependedByKeys(self, _graphene_info) -> List[GrapheneAssetKey]:
+    def resolve_dependedByKeys(self, _graphene_info) -> Sequence[GrapheneAssetKey]:
         # CrossRepoAssetDependedByLoader class loads all cross-repo asset dependencies workspace-wide.
         # In order to avoid recomputing workspace-wide values per asset node, we add a loader
         # that batch loads all cross-repo dependencies for the whole workspace.
-        check.invariant(
+        depended_by_loader = check.not_none(
             self._depended_by_loader,
             "depended_by_loader must exist in order to resolve dependedBy nodes",
         )
 
-        depended_by_asset_nodes = self._depended_by_loader.get_cross_repo_dependent_assets(
+        depended_by_asset_nodes = depended_by_loader.get_cross_repo_dependent_assets(
             self._repository_location.name,
             self._external_repository.name,
             self._external_asset_node.asset_key,
@@ -274,7 +278,7 @@ class GrapheneAssetNode(graphene.ObjectType):
             for dep in self._external_asset_node.dependencies
         ]
 
-    def resolve_dependencies(self, graphene_info) -> List[GrapheneAssetDependency]:
+    def resolve_dependencies(self, graphene_info) -> Sequence[GrapheneAssetDependency]:
         if not self._external_asset_node.dependencies:
             return []
 
@@ -293,10 +297,10 @@ class GrapheneAssetNode(graphene.ObjectType):
             for dep in self._external_asset_node.dependencies
         ]
 
-    def resolve_jobNames(self, _graphene_info) -> List[str]:
+    def resolve_jobNames(self, _graphene_info) -> Sequence[str]:
         return self._external_asset_node.job_names
 
-    def resolve_jobs(self, _graphene_info) -> List[GraphenePipeline]:
+    def resolve_jobs(self, _graphene_info) -> Sequence[GraphenePipeline]:
         job_names = self._external_asset_node.job_names or []
         return [
             GraphenePipeline(self._external_repository.get_full_external_pipeline(job_name))
@@ -306,7 +310,7 @@ class GrapheneAssetNode(graphene.ObjectType):
 
     def resolve_latestMaterializationByPartition(
         self, graphene_info, **kwargs
-    ) -> List[Optional[GrapheneMaterializationEvent]]:
+    ) -> Sequence[Optional[GrapheneMaterializationEvent]]:
         from ..implementation.fetch_assets import get_asset_materializations
 
         get_partition = (
@@ -342,7 +346,7 @@ class GrapheneAssetNode(graphene.ObjectType):
 
     def resolve_materializationCountByPartition(
         self, graphene_info
-    ) -> List[GrapheneMaterializationCount]:
+    ) -> Sequence[GrapheneMaterializationCount]:
         asset_key = self._external_asset_node.asset_key
         partition_keys = self.get_partition_keys()
 
@@ -355,7 +359,7 @@ class GrapheneAssetNode(graphene.ObjectType):
             for partition_key in partition_keys
         ]
 
-    def resolve_metadata_entries(self, _graphene_info) -> List[GrapheneMetadataEntry]:
+    def resolve_metadata_entries(self, _graphene_info) -> Sequence[GrapheneMetadataEntry]:
         return list(iterate_metadata_entries(self._external_asset_node.metadata_entries))
 
     def resolve_op(
@@ -368,13 +372,19 @@ class GrapheneAssetNode(graphene.ObjectType):
         else:
             return None
 
+    def resolve_opNames(self, _graphene_info) -> Sequence[str]:
+        return self._external_asset_node.op_names or []
+
+    def resolve_graphName(self, _graphene_info) -> Optional[str]:
+        return self._external_asset_node.graph_name
+
     def resolve_partitionDefinition(self, _graphene_info) -> Optional[str]:
         partitions_def_data = self._external_asset_node.partitions_def_data
         if partitions_def_data:
             return str(partitions_def_data.get_partitions_definition())
         return None
 
-    def resolve_partitionKeys(self, _graphene_info) -> List[str]:
+    def resolve_partitionKeys(self, _graphene_info) -> Sequence[str]:
         return self.get_partition_keys()
 
     def resolve_repository(self, graphene_info) -> "GrapheneRepository":
