@@ -1,10 +1,12 @@
+# pylint: disable=missing-graphene-docstring
 import graphene
-from dagster import check
-from dagster.core.snap import PipelineSnapshot
-from dagster.core.types.dagster_type import DagsterTypeKind
 from dagster_graphql.implementation.events import iterate_metadata_entries
 from dagster_graphql.schema.metadata import GrapheneMetadataEntry
 
+import dagster._check as check
+from dagster.core.snap import PipelineSnapshot
+from dagster.core.types.dagster_type import DagsterTypeKind
+
 from .config_types import GrapheneConfigType, to_config_type
 from .errors import (
     GrapheneDagsterTypeNotFoundError,
