@@ -1,6 +1,7 @@
+# pylint: disable=missing-graphene-docstring
 import graphene
 
-from dagster import check
+import dagster._check as check
 from dagster.core.host_representation import ExternalExecutionPlan
 from dagster.core.snap import ExecutionStepInputSnap, ExecutionStepOutputSnap, ExecutionStepSnap
 
