@@ -1,3 +1,4 @@
+# pylint: disable=missing-graphene-docstring
 import graphene
 from dagster_graphql.implementation.fetch_runs import (
     get_in_progress_runs_by_step,
@@ -6,7 +7,8 @@ from dagster_graphql.implementation.fetch_runs import (
 from dagster_graphql.implementation.fetch_solids import get_solid, get_solids
 from dagster_graphql.implementation.loader import RepositoryScopedBatchLoader
 
-from dagster import DagsterInstance, check
+from dagster import DagsterInstance
+from dagster import _check as check
 from dagster.core.host_representation import (
     ExternalRepository,
     GrpcServerRepositoryLocation,
