@@ -1,7 +1,8 @@
+# pylint: disable=missing-graphene-docstring
 import graphene
 import yaml
 
-from dagster import check
+import dagster._check as check
 from dagster.core.events import DagsterEventType
 from dagster.core.host_representation.external import ExternalExecutionPlan, ExternalPipeline
 from dagster.core.host_representation.external_data import ExternalPresetData
@@ -217,6 +218,7 @@ class GrapheneRun(graphene.ObjectType):
     pipelineName = graphene.NonNull(graphene.String)
     jobName = graphene.NonNull(graphene.String)
     solidSelection = graphene.List(graphene.NonNull(graphene.String))
+    assetSelection = graphene.List(graphene.NonNull(GrapheneAssetKey))
     resolvedOpSelection = graphene.List(graphene.NonNull(graphene.String))
     stats = graphene.NonNull(GrapheneRunStatsSnapshotOrError)
     stepStats = non_null_list(GrapheneRunStepStats)
@@ -286,6 +288,9 @@ class GrapheneRun(graphene.ObjectType):
     def resolve_solidSelection(self, _graphene_info):
         return self._pipeline_run.solid_selection
 
+    def resolve_assetSelection(self, _graphene_info):
+        return self._pipeline_run.asset_selection
+
     def resolve_resolvedOpSelection(self, _graphene_info):
         return self._pipeline_run.solids_to_execute
 
