@@ -1,6 +1,7 @@
+# pylint: disable=missing-graphene-docstring
 import graphene
 
-from dagster import check
+import dagster._check as check
 
 from ..errors import GrapheneError
 from .pipeline import GraphenePipeline
