@@ -1,8 +1,9 @@
+# pylint: disable=missing-graphene-docstring
 import graphene
 
 from ..errors import GraphenePipelineNotFoundError, GraphenePythonError
 from ..execution import GrapheneExecutionPlan
-from ..pipelines.config import GraphenePipelineConfigValidationInvalid
+from ..pipelines.config import GrapheneRunConfigValidationInvalid
 from ..pipelines.pipeline_errors import GrapheneInvalidSubsetError
 
 
@@ -10,7 +11,7 @@ class GrapheneExecutionPlanOrError(graphene.Union):
     class Meta:
         types = (
             GrapheneExecutionPlan,
-            GraphenePipelineConfigValidationInvalid,
+            GrapheneRunConfigValidationInvalid,
             GraphenePipelineNotFoundError,
             GrapheneInvalidSubsetError,
             GraphenePythonError,
