@@ -1,5 +1,6 @@
 import graphene
 
+import dagster._check as check
 from dagster.core.definitions.events import AssetKey
 from dagster.core.workspace.permissions import Permissions
 
@@ -9,6 +10,7 @@ from ...implementation.execution import (
     delete_pipeline_run,
     launch_pipeline_execution,
     launch_pipeline_reexecution,
+    launch_reexecution_from_parent_run,
     resume_partition_backfill,
     terminate_pipeline_execution,
     wipe_assets,
@@ -40,7 +42,12 @@ from ..errors import (
     GrapheneUnauthorizedError,
 )
 from ..external import GrapheneWorkspace, GrapheneWorkspaceLocationEntry
-from ..inputs import GrapheneAssetKeyInput, GrapheneExecutionParams, GrapheneLaunchBackfillParams
+from ..inputs import (
+    GrapheneAssetKeyInput,
+    GrapheneExecutionParams,
+    GrapheneLaunchBackfillParams,
+    GrapheneReexecutionParams,
+)
 from ..pipelines.pipeline import GrapheneRun
 from ..runs import (
     GrapheneLaunchRunReexecutionResult,
@@ -48,7 +55,11 @@ from ..runs import (
     parse_run_config_input,
 )
 from ..schedules import GrapheneStartScheduleMutation, GrapheneStopRunningScheduleMutation
-from ..sensors import GrapheneStartSensorMutation, GrapheneStopSensorMutation
+from ..sensors import (
+    GrapheneSetSensorCursorMutation,
+    GrapheneStartSensorMutation,
+    GrapheneStopSensorMutation,
+)
 from ..util import non_null_list
 
 
@@ -121,6 +132,8 @@ def create_execution_metadata(graphql_execution_metadata):
 
 
 class GrapheneDeletePipelineRunSuccess(graphene.ObjectType):
+    """Output indicating that a run was deleted."""
+
     runId = graphene.NonNull(graphene.String)
 
     class Meta:
@@ -128,6 +141,8 @@ class GrapheneDeletePipelineRunSuccess(graphene.ObjectType):
 
 
 class GrapheneDeletePipelineRunResult(graphene.Union):
+    """The output from deleting a run."""
+
     class Meta:
         types = (
             GrapheneDeletePipelineRunSuccess,
@@ -139,6 +154,8 @@ class GrapheneDeletePipelineRunResult(graphene.Union):
 
 
 class GrapheneDeleteRunMutation(graphene.Mutation):
+    """Deletes a run from storage."""
+
     Output = graphene.NonNull(GrapheneDeletePipelineRunResult)
 
     class Arguments:
@@ -155,6 +172,8 @@ class GrapheneDeleteRunMutation(graphene.Mutation):
 
 
 class GrapheneTerminatePipelineExecutionSuccess(graphene.Interface):
+    """Interface indicating that a run was terminated."""
+
     run = graphene.Field(graphene.NonNull(GrapheneRun))
 
     class Meta:
@@ -162,6 +181,8 @@ class GrapheneTerminatePipelineExecutionSuccess(graphene.Interface):
 
 
 class GrapheneTerminateRunSuccess(graphene.ObjectType):
+    """Output indicating that a run was terminated."""
+
     run = graphene.Field(graphene.NonNull(GrapheneRun))
 
     class Meta:
@@ -170,6 +191,8 @@ class GrapheneTerminateRunSuccess(graphene.ObjectType):
 
 
 class GrapheneTerminatePipelineExecutionFailure(graphene.Interface):
+    """Interface indicating that a run failed to terminate."""
+
     run = graphene.NonNull(GrapheneRun)
     message = graphene.NonNull(graphene.String)
 
@@ -178,6 +201,8 @@ class GrapheneTerminatePipelineExecutionFailure(graphene.Interface):
 
 
 class GrapheneTerminateRunFailure(graphene.ObjectType):
+    """Output indicating that a run failed to terminate."""
+
     run = graphene.NonNull(GrapheneRun)
     message = graphene.NonNull(graphene.String)
 
@@ -187,6 +212,8 @@ class GrapheneTerminateRunFailure(graphene.ObjectType):
 
 
 class GrapheneTerminateRunResult(graphene.Union):
+    """The output from a run termination."""
+
     class Meta:
         types = (
             GrapheneTerminateRunSuccess,
@@ -209,6 +236,7 @@ def create_execution_params_and_launch_pipeline_exec(graphene_info, execution_pa
 
 
 class GrapheneLaunchRunMutation(graphene.Mutation):
+    """Launches a job run."""
 
     Output = graphene.NonNull(GrapheneLaunchRunResult)
 
@@ -216,7 +244,6 @@ class GrapheneLaunchRunMutation(graphene.Mutation):
         executionParams = graphene.NonNull(GrapheneExecutionParams)
 
     class Meta:
-        description = "Launch a run via the run launcher configured on the instance."
         name = "LaunchRunMutation"
 
     @capture_error
@@ -228,13 +255,14 @@ class GrapheneLaunchRunMutation(graphene.Mutation):
 
 
 class GrapheneLaunchBackfillMutation(graphene.Mutation):
+    """Launches a set of partition backfill runs."""
+
     Output = graphene.NonNull(GrapheneLaunchBackfillResult)
 
     class Arguments:
         backfillParams = graphene.NonNull(GrapheneLaunchBackfillParams)
 
     class Meta:
-        description = "Launches a set of partition backfill runs via the run launcher configured on the instance."
         name = "LaunchBackfillMutation"
 
     @capture_error
@@ -244,13 +272,14 @@ class GrapheneLaunchBackfillMutation(graphene.Mutation):
 
 
 class GrapheneCancelBackfillMutation(graphene.Mutation):
+    """Cancels a set of partition backfill runs."""
+
     Output = graphene.NonNull(GrapheneCancelBackfillResult)
 
     class Arguments:
         backfillId = graphene.NonNull(graphene.String)
 
     class Meta:
-        description = "Marks a partition backfill as canceled."
         name = "CancelBackfillMutation"
 
     @capture_error
@@ -260,13 +289,14 @@ class GrapheneCancelBackfillMutation(graphene.Mutation):
 
 
 class GrapheneResumeBackfillMutation(graphene.Mutation):
+    """Retries a set of partition backfill runs."""
+
     Output = graphene.NonNull(GrapheneResumeBackfillResult)
 
     class Arguments:
         backfillId = graphene.NonNull(graphene.String)
 
     class Meta:
-        description = "Retries a set of partition backfill runs via the run launcher configured on the instance."
         name = "ResumeBackfillMutation"
 
     @capture_error
@@ -286,30 +316,48 @@ def create_execution_params_and_launch_pipeline_reexec(graphene_info, execution_
 
 
 class GrapheneLaunchRunReexecutionMutation(graphene.Mutation):
+    """Re-executes a job run."""
+
     Output = graphene.NonNull(GrapheneLaunchRunReexecutionResult)
 
     class Arguments:
-        executionParams = graphene.NonNull(GrapheneExecutionParams)
+        executionParams = graphene.Argument(GrapheneExecutionParams)
+        reexecutionParams = graphene.Argument(GrapheneReexecutionParams)
 
     class Meta:
-        description = "Re-launch a run via the run launcher configured on the instance"
         name = "LaunchRunReexecutionMutation"
 
     @capture_error
     @check_permission(Permissions.LAUNCH_PIPELINE_REEXECUTION)
     def mutate(self, graphene_info, **kwargs):
-        return create_execution_params_and_launch_pipeline_reexec(
-            graphene_info,
-            execution_params_dict=kwargs["executionParams"],
+        execution_params = kwargs.get("executionParams")
+        reexecution_params = kwargs.get("reexecutionParams")
+        check.invariant(
+            bool(execution_params) != bool(reexecution_params),
+            "Must only provide one of either executionParams or reexecutionParams",
         )
 
+        if execution_params:
+            return create_execution_params_and_launch_pipeline_reexec(
+                graphene_info,
+                execution_params_dict=kwargs["executionParams"],
+            )
+        else:
+            return launch_reexecution_from_parent_run(
+                graphene_info,
+                reexecution_params["parentRunId"],
+                reexecution_params["strategy"],
+            )
+
 
 class GrapheneTerminateRunPolicy(graphene.Enum):
+    """The type of termination policy to use for a run."""
+
     # Default behavior: Only mark as canceled if the termination is successful, and after all
-    # resources peforming the execution have been shut down.
+    # resources performing the execution have been shut down.
     SAFE_TERMINATE = "SAFE_TERMINATE"
 
-    # Immediately mark the pipelie as canceled, whether or not the termination was successful.
+    # Immediately mark the run as canceled, whether or not the termination was successful.
     # No guarantee that the execution has actually stopped.
     MARK_AS_CANCELED_IMMEDIATELY = "MARK_AS_CANCELED_IMMEDIATELY"
 
@@ -318,6 +366,8 @@ class GrapheneTerminateRunPolicy(graphene.Enum):
 
 
 class GrapheneTerminateRunMutation(graphene.Mutation):
+    """Terminates a run."""
+
     Output = graphene.NonNull(GrapheneTerminateRunResult)
 
     class Arguments:
@@ -331,13 +381,15 @@ class GrapheneTerminateRunMutation(graphene.Mutation):
     @check_permission(Permissions.TERMINATE_PIPELINE_EXECUTION)
     def mutate(self, graphene_info, **kwargs):
         return terminate_pipeline_execution(
-            graphene_info,
+            graphene_info.context.instance,
             kwargs["runId"],
             kwargs.get("terminatePolicy", GrapheneTerminateRunPolicy.SAFE_TERMINATE),
         )
 
 
 class GrapheneReloadRepositoryLocationMutationResult(graphene.Union):
+    """The output from reloading a code location server."""
+
     class Meta:
         types = (
             GrapheneWorkspaceLocationEntry,
@@ -350,6 +402,8 @@ class GrapheneReloadRepositoryLocationMutationResult(graphene.Union):
 
 
 class GrapheneShutdownRepositoryLocationSuccess(graphene.ObjectType):
+    """Output indicating that a code location server was shut down."""
+
     repositoryLocationName = graphene.NonNull(graphene.String)
 
     class Meta:
@@ -357,6 +411,8 @@ class GrapheneShutdownRepositoryLocationSuccess(graphene.ObjectType):
 
 
 class GrapheneShutdownRepositoryLocationMutationResult(graphene.Union):
+    """The output from shutting down a code location server."""
+
     class Meta:
         types = (
             GrapheneShutdownRepositoryLocationSuccess,
@@ -368,6 +424,8 @@ class GrapheneShutdownRepositoryLocationMutationResult(graphene.Union):
 
 
 class GrapheneReloadRepositoryLocationMutation(graphene.Mutation):
+    """Reloads a code location server."""
+
     Output = graphene.NonNull(GrapheneReloadRepositoryLocationMutationResult)
 
     class Arguments:
@@ -397,6 +455,8 @@ class GrapheneReloadRepositoryLocationMutation(graphene.Mutation):
 
 
 class GrapheneShutdownRepositoryLocationMutation(graphene.Mutation):
+    """Shuts down a code location server."""
+
     Output = graphene.NonNull(GrapheneShutdownRepositoryLocationMutationResult)
 
     class Arguments:
@@ -421,6 +481,8 @@ class GrapheneShutdownRepositoryLocationMutation(graphene.Mutation):
 
 
 class GrapheneReloadWorkspaceMutationResult(graphene.Union):
+    """The output from reloading the workspace."""
+
     class Meta:
         types = (
             GrapheneWorkspace,
@@ -431,6 +493,8 @@ class GrapheneReloadWorkspaceMutationResult(graphene.Union):
 
 
 class GrapheneReloadWorkspaceMutation(graphene.Mutation):
+    """Reloads the workspace and its code location servers."""
+
     Output = graphene.NonNull(GrapheneReloadWorkspaceMutationResult)
 
     class Meta:
@@ -444,6 +508,8 @@ class GrapheneReloadWorkspaceMutation(graphene.Mutation):
 
 
 class GrapheneAssetWipeSuccess(graphene.ObjectType):
+    """Output indicating that asset history was deleted."""
+
     assetKeys = non_null_list(GrapheneAssetKey)
 
     class Meta:
@@ -451,6 +517,8 @@ class GrapheneAssetWipeSuccess(graphene.ObjectType):
 
 
 class GrapheneAssetWipeMutationResult(graphene.Union):
+    """The output from deleting asset history."""
+
     class Meta:
         types = (
             GrapheneAssetNotFoundError,
@@ -462,6 +530,8 @@ class GrapheneAssetWipeMutationResult(graphene.Union):
 
 
 class GrapheneAssetWipeMutation(graphene.Mutation):
+    """Deletes asset history from storage."""
+
     Output = graphene.NonNull(GrapheneAssetWipeMutationResult)
 
     class Arguments:
@@ -480,6 +550,8 @@ class GrapheneAssetWipeMutation(graphene.Mutation):
 
 
 class GrapheneLogTelemetrySuccess(graphene.ObjectType):
+    """Output indicating that telemetry was logged."""
+
     action = graphene.NonNull(graphene.String)
 
     class Meta:
@@ -487,6 +559,8 @@ class GrapheneLogTelemetrySuccess(graphene.ObjectType):
 
 
 class GrapheneLogTelemetryMutationResult(graphene.Union):
+    """The output from logging telemetry."""
+
     class Meta:
         types = (
             GrapheneLogTelemetrySuccess,
@@ -496,6 +570,8 @@ class GrapheneLogTelemetryMutationResult(graphene.Union):
 
 
 class GrapheneLogTelemetryMutation(graphene.Mutation):
+    """Log telemetry about the Dagster instance."""
+
     Output = graphene.NonNull(GrapheneLogTelemetryMutationResult)
 
     class Arguments:
@@ -518,6 +594,8 @@ class GrapheneLogTelemetryMutation(graphene.Mutation):
 
 
 class GrapheneDagitMutation(graphene.ObjectType):
+    """Mutations to programatically interact with your Dagster instance."""
+
     class Meta:
         name = "DagitMutation"
 
@@ -528,6 +606,7 @@ class GrapheneDagitMutation(graphene.ObjectType):
     start_schedule = GrapheneStartScheduleMutation.Field()
     stop_running_schedule = GrapheneStopRunningScheduleMutation.Field()
     start_sensor = GrapheneStartSensorMutation.Field()
+    set_sensor_cursor = GrapheneSetSensorCursorMutation.Field()
     stop_sensor = GrapheneStopSensorMutation.Field()
     terminate_pipeline_execution = GrapheneTerminateRunMutation.Field()
     terminate_run = GrapheneTerminateRunMutation.Field()
