@@ -1,6 +1,7 @@
+# pylint: disable=missing-graphene-docstring
 import graphene
 
-from dagster import check
+import dagster._check as check
 from dagster.core.host_representation import RepresentedPipeline
 
 from ..implementation.run_config_schema import resolve_is_run_config_valid
