@@ -1,3 +1,4 @@
+# pylint: disable=missing-graphene-docstring
 from functools import lru_cache
 
 import graphene
@@ -5,7 +6,7 @@ from dagster_graphql.implementation.events import iterate_metadata_entries
 from dagster_graphql.schema.logs.events import GrapheneRunStepStats
 from dagster_graphql.schema.metadata import GrapheneMetadataEntry
 
-from dagster import check
+import dagster._check as check
 from dagster.core.definitions import NodeHandle
 from dagster.core.host_representation import RepresentedPipeline
 from dagster.core.host_representation.historical import HistoricalPipeline
@@ -407,7 +408,7 @@ class ISolidDefinitionMixin:
         else:
             repo_handle = self._represented_pipeline.repository_handle
             origin = repo_handle.repository_location_origin
-            location = graphene_info.context.get_location(origin.location_name)
+            location = graphene_info.context.get_repository_location(origin.location_name)
             ext_repo = location.get_repository(repo_handle.repository_name)
             nodes = [
                 node
