@@ -3,7 +3,7 @@ from contextlib import contextmanager
 from dagster_graphql.schema import create_schema
 from graphql import graphql
 
-from dagster import check
+import dagster._check as check
 from dagster.core.instance import DagsterInstance
 from dagster.core.workspace import WorkspaceProcessContext
 from dagster.core.workspace.load_target import PythonFileTarget
@@ -96,9 +96,35 @@ def infer_repository_selector(graphql_context):
     }
 
 
-def infer_pipeline_selector(graphql_context, pipeline_name, solid_selection=None):
+def infer_job_or_pipeline_selector(
+    graphql_context,
+    pipeline_name,
+    solid_selection=None,
+    asset_selection=None,
+):
     selector = infer_repository_selector(graphql_context)
-    selector.update({"pipelineName": pipeline_name, "solidSelection": solid_selection})
+    selector.update(
+        {
+            "pipelineName": pipeline_name,
+            "solidSelection": solid_selection,
+            "assetSelection": asset_selection,
+        }
+    )
+    return selector
+
+
+def infer_pipeline_selector(
+    graphql_context,
+    pipeline_name,
+    solid_selection=None,
+):
+    selector = infer_repository_selector(graphql_context)
+    selector.update(
+        {
+            "pipelineName": pipeline_name,
+            "solidSelection": solid_selection,
+        }
+    )
     return selector
 
 
